@@ -1,4 +1,8 @@
 # frozen_string_literal: true
+
+require "open3"
+require "fileutils"
+
 module RubyRunner
   include FileUtils
 
